package io.renren.modules.app.controller;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestAttribute;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import io.renren.common.utils.R;
import io.renren.modules.admin.entity.AttendersEntity;
import io.renren.modules.admin.entity.PaymentEntity;
import io.renren.modules.admin.service.AttendersService;
import io.renren.modules.admin.service.PaymentService;
import io.renren.modules.app.annotation.Login;
import io.renren.modules.app.annotation.LoginUser;
import io.renren.modules.app.entity.UserEntity;
import io.renren.modules.app.service.UserService;



/**
 * 
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-21 15:10:27
 */
@RestController
@RequestMapping("app/order")
public class OrderController {
    @Autowired
    private AttendersService attendersService;

    @Autowired
    private UserService userService;

    @Autowired
    private PaymentService paymentService;
    
    
    /**
     * 订单列表
     */
    @Login
    @GetMapping("/list")
    public R orderList(@RequestAttribute("userId") Integer userId){
        System.out.println(userId);
        Long memberId = Long.valueOf(userId);        

        List<Map<String, Object>> orderList = userService.queryOrderList(memberId);        

        return R.ok().put("orderList", orderList);
    }

    /**
     * 保存
     */
    @Login
    @PostMapping("/save")
    public R save(@RequestBody Map<String, Object> params, @LoginUser UserEntity user){
        Long meetingId = Long.valueOf(params.get("meetingId").toString());
        AttendersEntity attendersEntity = new AttendersEntity();
        attendersEntity.setMeetingId(meetingId);
        attendersEntity.setMemberId(user.getUserId());
        attendersEntity.setName(user.getUsername());
        attendersEntity.setPhone(user.getPhone());
        attendersEntity.setEmail(user.getEmail());
        attendersEntity.setTypeId(Long.valueOf(params.get("typeId").toString()));
        attendersEntity.setRoom(Integer.valueOf(params.get("room").toString()));
        attendersEntity.setTransfer(Integer.valueOf(params.get("transfer").toString()));
        attendersEntity.setCreateTime(new Date());
        
        attendersService.save(attendersEntity);
        // System.out.println(attendersEntity.getId());

        // 付款信息
        PaymentEntity paymentEntity = new PaymentEntity();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddhhmmss");
        String nowtime = sdf.format(new Date());
        // System.out.println(time);
        Integer fourRandom = Integer.valueOf((int)((Math.random()*9+1)*1000));
        paymentEntity.setOrderId("FY" + nowtime + fourRandom);
        paymentEntity.setMeetingId(meetingId);
        paymentEntity.setAttendersId(attendersEntity.getId());
        paymentEntity.setPayType(1);
        paymentEntity.setTaxTitle(params.get("taxTitle").toString());
        paymentEntity.setTaxNumber(params.get("taxNumber").toString());
        paymentEntity.setAddrPhone(params.get("addPhone").toString());
        paymentEntity.setBankAddrAccount(params.get("bankAddrAccount").toString());
        paymentEntity.setTaxAddress(params.get("taxAddress").toString());
        paymentEntity.setCreateTime(new Date());

        paymentService.save(paymentEntity);

        return R.ok();
    }

    /**
     * 修改
     */
    @Login
    @PostMapping("/update")
    public R update(@RequestBody AttendersEntity attenders){
		attendersService.updateById(attenders);

        return R.ok();
    }

    /**
     * 删除
     */
    @Login
    @PostMapping("/delete")
    public R delete(@RequestBody Long[] ids){
		attendersService.removeByIds(Arrays.asList(ids));

        return R.ok();
    }

}
